
Changelog
=========

0.2.1 (2023-12-31)
------------------
* 🍰 Now On PyPI

With this release, `archive-steam-reviews` is now available on PyPI. You can install it with::

  pip install archive-steam-reviews

The functionality has not changed. 

📦 Python packaging by `🦄 Brie <https://brie.dev>`_.

0.1.0 (2023-10-28)
------------------

* First announced at https://log.manuelgrabowski.de/post/archive-steam-reviews/
